C E F G I N T V W
All Classes All Packages
All Classes All Packages
All Classes All Packages
C
- cancel() - Method in class io.github.msdk.normalization.compound.FeatureNormalizationByCompoundMethod
E
- execute() - Method in class io.github.msdk.normalization.compound.FeatureNormalizationByCompoundMethod
F
- FeatureNormalizationByCompoundMethod - Class in io.github.msdk.normalization.compound
-
This class normalized a list of feature table columns based on a set of features.
- FeatureNormalizationByCompoundMethod(FeatureTable, NormalizationType, List<FeatureTableRow>, Integer) - Constructor for class io.github.msdk.normalization.compound.FeatureNormalizationByCompoundMethod
-
Constructor for FeatureNormalizationByCompoundMethod.
G
- getFinishedPercentage() - Method in class io.github.msdk.normalization.compound.FeatureNormalizationByCompoundMethod
- getResult() - Method in class io.github.msdk.normalization.compound.FeatureNormalizationByCompoundMethod
I
- io.github.msdk.normalization.compound - package io.github.msdk.normalization.compound
N
- NEAREST_STANDARD - io.github.msdk.normalization.compound.NormalizationType
- NormalizationType - Enum in io.github.msdk.normalization.compound
-
NormalizationType class.
T
- toString() - Method in enum io.github.msdk.normalization.compound.NormalizationType
V
- valueOf(String) - Static method in enum io.github.msdk.normalization.compound.NormalizationType
-
Returns the enum constant of this type with the specified name.
- values() - Static method in enum io.github.msdk.normalization.compound.NormalizationType
-
Returns an array containing the constants of this enum type, in the order they are declared.
W
- WEIGHTED_CONTRIBUTION - io.github.msdk.normalization.compound.NormalizationType
All Classes All Packages